@@ -1,7 +1,7 @@
 package Org::To::HTML;
 
-our $DATE = '2016-11-06'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2016-11-14'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -113,7 +113,7 @@ sub org_to_html {
         return [400, "Please specify source_file/source_str"];
     }
 
-    my $obj = __PACKAGE__->new(
+    my $obj = ($args{_class} // __PACKAGE__)->new(
         include_tags => $args{include_tags},
         exclude_tags => $args{exclude_tags},
         css_url      => $args{css_url},
@@ -397,7 +397,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.17 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-11-06.
+This document describes version 0.18 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-11-14.
 
 =head1 SYNOPSIS
 
@@ -535,7 +535,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTM
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
 
 =head1 BUGS
 
